@@ -6,8 +6,8 @@ use strict qw(subs vars refs);				# Make sure we can't mess up
 use warnings FATAL => 'all';				# Enable warnings to catch errors
 
 # Initialize our version
-# $Revision: 1226 $
-our $VERSION = '1.10';
+# $Revision: 1238 $
+our $VERSION = '1.11';
 
 # Use Error.pm's try/catch semantics
 use Error qw( :try );
@@ -455,8 +455,12 @@ sub DB_DO {
 					$rows_affected = $sth->execute();
 				}
 
-				# Get the last insert id ( make this portable! )
-                                $last_id = $DB->last_insert_id( undef, undef, undef, undef );
+				try {
+					# Get the last insert id ( make this portable! )
+					$last_id = $DB->last_insert_id( undef, undef, undef, undef );
+				} catch Error with {
+					# Ignore this error!
+				};
 			} catch Error with {
 				die $sth->errstr;
 			};
